@@ -327,11 +327,12 @@ class VariableClMigrateData(UserHelper, TableVariable):
 
     def init(self):
         self.help = _("add a user to the installed system. USER is username. "
-                      "ADMIN is administrator rights (none, all, update, "
-                      "none by default). "
+                      "ADMIN is administrator rights ({alllist}, "
+                      "{none_value} by default). "
                       "GROUPS is list user supplimentary groups "
                       "(comma delimeter). "
-                      "Use 'none' value to discard user migration")
+                      "Use '{none_value}' value to discard user migration").format(
+                        alllist="none, update, all", none_value="none")
         self.label = _("Migrating users")
 
     def set(self, value):
@@ -397,8 +398,8 @@ class VariableClMigrateAdmin(UserHelper, Variable):
     def choice(self):
         return [
             ("", ""),
-            ("all", _("Full access")),
             ("update", _("System update")),
+            ("all", _("Full access")),
         ]
 
     @classmethod
@@ -425,7 +426,7 @@ class VariableClMigrateUserGroups(UserHelper, Variable):
     Migrate users groups
     """
     type = 'choice-list-list'
-    defaultGroupList = sorted(["users", "wheel", "audio", "cdrom", "video",
+    defaultGroupList = sorted(["users", "audio", "cdrom", "video",
                         "cdrw", "usb", "plugdev", "games", "lp", "scanner",
                         "uucp"])
     default_value = "default"
